--****************************************************************************************************
-- Client Lua Script for DisplayStat
-- Copyright (c) NCsoft. All rights reserved
-- Created by Mika
-- Last modified: 28/07/14
-- Version: 0.9 
--****************************************************************************************************

--****************************************************************************************************
-- List of used libs, that need for this addon.
--****************************************************************************************************
require "Apollo"
require "Window"
require "GameLib"



--****************************************************************************************************
-- DisplayStat Module Definition
--****************************************************************************************************
local DisplayStat = {} 

--****************************************************************************************************
-- DisplayStat Variables
--****************************************************************************************************
local ConfigMinVersion = 7 -- Minumum version for config data to load it.
local cSlashCommand = "ds"
local cAddonName = "DisplayStat"
local cHasConfigureFunction = true
local cConfigureButtonText = "DisplayStat"
local cXmlDoc = "DisplayStat.xml"

--****************************************************************************************************
-- Initialization
--****************************************************************************************************
------------------------------------------------------------------------------------------------------
-- DisplayStat new
------------------------------------------------------------------------------------------------------
function DisplayStat:new(o)
 	o = o or {}
 	setmetatable(o, self)
 	self.__index = self

 	o.Config = {} -- Property to saved and load config data.
 	o.Config.IsVisible = true 
 	o.Config.PositionMain = -- Default position for DisplayStatHoloForm.
 	{
  		Bottom = 600,
  		Left = 10,
  		Right = 310,
  		Top = 450,
 	}
	o.Config.PositionConfig =
 	{
  		Bottom = 600,
  		Left = 350,
  		Right = 850,
  		Top = 0,
 	}

	o.Config.IsCustomNameChecked = false

	

	o.Config.Attribute = {}

	o.Config.Attribute.MaxHealth = {
		name = Apollo.GetString("Character_MaxHealthLabel"),
		customName = "maxHP" }
		
	o.Config.Attribute.MaxShield = {
		name = Apollo.GetString("Character_MaxShieldLabel"),
		customName = "maxShield" }
	
	o.Config.Attribute.AssaultPower = {
		name = Apollo.GetString("AttributeAssaultPower"),
		customName = "AP" }
		
	o.Config.Attribute.SupportPower = {
		name = Apollo.GetString("AttributeSupportPower"),
		customName = "SP" }

	o.Config.Attribute.Armor = {
		name = Apollo.GetString("CRB_Armor"),
		customName = "Armor" }

	o.Config.Attribute.Strikethrough = {
		name = Apollo.GetString("Character_StrikethroughLabel"),
		customName = "Hit" }

	o.Config.Attribute.CritChance = {
		name = Apollo.GetString("Character_CritChanceLabel"),
		customName = "Crit" }

	o.Config.Attribute.CritSeverity = {
		name = Apollo.GetString("Character_CritSeverityLabel"),
		customName = "CritSev" }
		
	o.Config.Attribute.ArmorPen = {
		name = Apollo.GetString("Character_ArmorPenLabel"),
		customName = "ArmorPen" }

	o.Config.Attribute.ShieldPen = {
		name = Apollo.GetString("Character_ShieldPenLabel"),
		customName = "ShieldPen" }

	o.Config.Attribute.Lifesteal = {
		name = Apollo.GetString("Character_LifestealLabel"),
		customName = "Lifesteal" }

	o.Config.Attribute.CooldownReduction = {
		name = Apollo.GetString("Character_HasteLabel"),
		customName = "CDRed" }

	o.Config.Attribute.ShieldRegenPercent = {
		name = Apollo.GetString("Character_ShieldRegenPercentLabel"),
		customName = "ShieldRegen" }

	o.Config.Attribute.ShieldReboot = {
		name = Apollo.GetString("Character_ShieldRebootLabel"),
		customName = "ShieldReboot" }

	o.Config.Attribute.PhysicalMit = {
		name = Apollo.GetString("Character_PhysicalMitLabel"),
		customName = "PhysRes" }

	o.Config.Attribute.TechMit = {
		name = Apollo.GetString("Character_TechMitLabel"),
		customName = "TechRes" }

	o.Config.Attribute.MagicMit = {
		name = Apollo.GetString("Character_MagicMitLabel"),
		customName = "MagicRes" }

	o.Config.Attribute.Deflect = {
		name = Apollo.GetString("Character_DeflectLabel"),
		customName = "Deflect" }

	o.Config.Attribute.DeflectCrit = {
		name = Apollo.GetString("Character_DeflectCritLabel"),
		customName = "DeflectCrit" }

	o.Config.Attribute.CCDuration = {
		name = Apollo.GetString("Character_ResilianceLabel"),
		customName = "CCRed" }

	o.Config.Attribute.ManaRecovery = {
		name = Apollo.GetString("Character_ManaRecoveryLabel"),
		customName = "FocusRegen" }

	o.Config.Attribute.ManaCostRed = {
		name = Apollo.GetString("Character_ManaCostRedLabel"),
		customName = "FocusCostRed" }

	--[[o.Config.Attribute.PvPOffense = {
		name = Apollo.GetString("Character_PvPOffenseLabel"),
		customName = "PvPAtk" }

	o.Config.Attribute.PvPHeal = {
		name = Apollo.GetString("Character_PvPHealLabel"),
		customName = "PvPHeal" }

	o.Config.Attribute.PvPDef = {
		name = Apollo.GetString("Character_PvPDefLabel"),
		customName = "PvPDef" }]]



	-- Attributes Default Settings
	o.Config.bMaxHealth = false
	o.Config.bMaxShield = false
	o.Config.bAssaultPower = true
	o.Config.bSupportPower = true
	o.Config.bArmor = true
	o.Config.bStrikethrough = false
	o.Config.bCritChance = false
	o.Config.bCritSeverity = false
	o.Config.bArmorPen = false
	o.Config.bShieldPen = false
	o.Config.bLifesteal = false
	o.Config.bCooldownReduction = false
	o.Config.bShieldRegenPercent = false
	o.Config.bShieldReboot = false
	o.Config.bPhysicalMit = false
	o.Config.bTechMit = false
	o.Config.bMagicMit = false
	o.Config.bDeflect = false
	o.Config.bDeflectCrit = false
	o.Config.bCCDuration = false
	o.Config.bManaRecovery = false
	o.Config.bManaCostRed = false
	--o.Config.bPvPOffense = false
	--o.Config.bPvPHeal = false
	--o.Config.bPvPDef = false


	-- Default Templates
	o.Config.TemplateList = {
	{
		TemplateName = "dps",
		tMaxHealth = false,
		tMaxShield = false,
		tAssaultPower = true,
		tSupportPower = false,
		tArmor = false,
		tStrikethrough = false,
		tCritChance = true,
		tCritSeverity = false,
		tArmorPen = false,
		tShieldPen = false,
		tLifesteal = false,
		tCooldownReduction = false,
		tShieldRegenPercent = false,
		tShieldReboot = false,
		tPhysicalMit = false,
		tTechMit = false,
		tMagicMit = false,
		tDeflect = false,
		tDeflectCrit = false,
		tCCDuration = false,
		tManaRecovery = false,
		tManaCostRed = false,
		--tPvPOffense = false,
		--tPvPHeal = false,
		--tPvPDefPercent = false
	},
	{
		TemplateName = "heal",
		tMaxHealth = false,
		tMaxShield = false,
		tAssaultPower = false,
		tSupportPower = true,
		tArmor = false,
		tStrikethrough = false,
		tCritChance = true,
		tCritSeverity = false,
		tArmorPen = false,
		tShieldPen = false,
		tLifesteal = false,
		tCooldownReduction = false,
		tShieldRegenPercent = false,
		tShieldReboot = false,
		tPhysicalMit = false,
		tTechMit = false,
		tMagicMit = false,
		tDeflect = false,
		tDeflectCrit = false,
		tCCDuration = false,
		tManaRecovery = true,
		tManaCostRed = false,
		--tPvPOffense = false,
		--tPvPHeal = false,
		--tPvPDef = false
	},
	{
		TemplateName = "tank",
		tMaxHealth = false,
		tMaxShield = false,
		tAssaultPower = false,
		tSupportPower = true,
		tArmor = true,
		tStrikethrough = false,
		tCritChance = false,
		tCritSeverity = false,
		tArmorPen = false,
		tShieldPen = false,
		tLifesteal = false,
		tCooldownReduction = false,
		tShieldRegenPercent = false,
		tShieldReboot = false,
		tPhysicalMit = false,
		tTechMit = false,
		tMagicMit = false,
		tDeflect = true,
		tDeflectCrit = false,
		tCCDuration = false,
		tManaRecovery = false,
		tManaCostRed = false,
		--tPvPOffense = false,
		--tPvPHeal = false,
		--tPvPDef = false
	}
	}

	-- Version of config.
 	o.Config.Version = 7  
	
	return o
end

------------------------------------------------------------------------------------------------------
-- DisplayStat Init
------------------------------------------------------------------------------------------------------
function DisplayStat:Init()
 	local tDependencies = {}
 	Apollo.RegisterAddon(self, cHasConfigureFunction, cConfigureButtonText, tDependencies)

end
 
------------------------------------------------------------------------------------------------------
-- DisplayStat OnDocLoaded
------------------------------------------------------------------------------------------------------
function DisplayStat:OnDocLoaded()


 	if self.xmlDoc ~= nil and self.xmlDoc:IsLoaded() then

	--Main Timer
	Apollo.CreateTimer("MainTimer", 0.5, true, self)
	Apollo.RegisterTimerHandler("MainTimer", "OnMainTimer", self)
	self.Config.prvAttribute = 
	{
		MaxHealth = 0,
		MaxShield = 0,
		AssaultPower = 0,
		SupportPower = 0,
		Armor = 0,
		Strikethrough = 0,
		CritChance = 0,
		tCritSeverity = 0,
		ArmorPen = 0,
		ShieldPen = 0,
		Lifesteal = 0,
		CooldownReduction = 0,
		ShieldRegenPercent = 0,
		ShieldReboot = 0,
		PhysicalMit = 0,
		TechMit = 0,
		MagicMit = 0,
		Deflect = 0,
		DeflectCrit = 0,
		CCDuration = 0,
		ManaRecovery = 0,
		ManaCostRed = 0,
		--PvPOffense = 0,
		--PvPHeal = 0,
		--PvPDef = 0
	}
  	-- Load windows form
  		self.MainForm = Apollo.LoadForm(self.xmlDoc, "DisplayStatHoloForm", nil, self)
  		self.ConfigForm = Apollo.LoadForm(self.xmlDoc, "DisplayStatConfigForm", nil, self)

  		if self.MainForm == nil then
   			Apollo.AddAddonErrorText(self, "Could not load the holo window for some reason.")
 		else
   			-- Close windows by default
   			self.MainForm:Show(false, true)
   			self.ConfigForm:Show(false, true)
			self.ConfigForm:FindChild("CustomNameWindowButton"):AttachWindow(self.ConfigForm:FindChild("CustomNameWindow"))
			self.ConfigForm:FindChild("CustomNameWindow"):Show(false, true)
			
		   	if self.Config ~= nil then
		    	-- Restore saved window positions.
		    	if self.Config.PositionMain ~= nil then
		     		self.MainForm:SetAnchorOffsets(
		      		self.Config.PositionMain.Left,
		      		self.Config.PositionMain.Top,
		      		self.Config.PositionMain.Right,
		      		self.Config.PositionMain.Bottom)
		    	end
				
				if self.Config.PositionConfig ~= nil then
					self.ConfigForm:SetAnchorOffsets(
		      		self.Config.PositionConfig.Left,
		      		self.Config.PositionConfig.Top,
		      		self.Config.PositionConfig.Right,
		      		self.Config.PositionConfig.Bottom)
				end
				-- Restore templates
				if self.Config.TemplateList ~= nil then
					
					for index in pairs(self.Config.TemplateList) do
						local Template = Apollo.LoadForm(self.xmlDoc, "SelectTemplateButton", self.ConfigForm:FindChild("TemplateListContainer"), self)
						Template:SetText(self.Config.TemplateList[index].TemplateName)
						Template:SetData(self.Config.TemplateList[index].TemplateName)
					end
					self.ConfigForm:FindChild("TemplateListContainer"):ArrangeChildrenVert()
				end
				
				-- Restore Selected Stats
				self:MatchWithConfig()
				self:MatchWithCustomName()
				
		   end

   			-- The xmlDoc is no longer needed.
   			self.xmlDoc = nil
   			-- View can be open via the command /DisplayStat or menu entry.
   			Apollo.RegisterSlashCommand(cSlashCommand, "OnDisplayStatCall", self)
   			Apollo.RegisterEventHandler("DisplayStatMenuClicked", "OnDisplayStatCall", self)

			

   			-- Open the main form if it was visible before.
   			if self.Config ~= nil and self.Config.IsVisible == true then
    			self:MainShow()
   			end
  		end
 	end
end

------------------------------------------------------------------------------------------------------
-- DisplayStat OnInterfaceMenuListHasLoaded
-- Adds a menu entry for this addon.
------------------------------------------------------------------------------------------------------
function DisplayStat:OnInterfaceMenuListHasLoaded()
 	Event_FireGenericEvent(
  		"InterfaceMenuList_NewAddOn",
  		cAddonName,
  		{
  		 "DisplayStatMenuClicked",
   		 "",
    	 "IconSprites:Icon_Windows32_UI_CRB_InterfaceMenu_Abilities"
  		} )
end

------------------------------------------------------------------------------------------------------
-- DisplayStat OnLoad
-- Load the form xml file.
------------------------------------------------------------------------------------------------------
function DisplayStat:OnLoad()
 	self.xmlDoc = XmlDoc.CreateFromFile(cXmlDoc)
 	self.xmlDoc:RegisterCallback("OnDocLoaded", self)
 	-- Register for the InterfaceMenuListHasLoaded event to add a own menu item.
 	Apollo.RegisterEventHandler("InterfaceMenuListHasLoaded", "OnInterfaceMenuListHasLoaded", self)
end

------------------------------------------------------------------------------------------------------
-- DisplayStat OnRestore
-- Load the saved settings for the addon.
------------------------------------------------------------------------------------------------------
function DisplayStat:OnRestore(type, savedData)
 	if type == GameLib.CodeEnumAddonSaveLevel.Character then
  		if savedData ~= nil and
     	savedData.Version ~= nil and
     	savedData.Version >= ConfigMinVersion then
   			-- Saved configs only used if they compatible with the minimum version.
   			self.Config = savedData
 	 	end
 	end
end

------------------------------------------------------------------------------------------------------
-- DisplayStat OnSave
-- Save the settings for the addon per Character.
------------------------------------------------------------------------------------------------------
function DisplayStat:OnSave(eType)
 	local result = nil
 	if eType == GameLib.CodeEnumAddonSaveLevel.Character then
  		result = self.Config
 	end
 	return result
end

------------------------------------------------------------------------------------------------------
-- DisplayStat OnDisplayStatCall
-- Function on SlashCommand "/ds"
------------------------------------------------------------------------------------------------------
function DisplayStat:OnDisplayStatCall()
 	if self.MainForm:IsShown() == true then
  		self:MainHide()
 	else
  	self:MainShow()
 	end
end

------------------------------------------------------------------------------------------------------
-- DisplayStat OnClose
-- Remove handler for update target info and hide window.
------------------------------------------------------------------------------------------------------
function DisplayStat:OnClose(wndHandler, wndControl, eMouseButtons)
 	self:MainHide()
end

------------------------------------------------------------------------------------------------------
-- DisplayStat OnWindowMoveMain
-- Remove handler for update target info and hide window.
------------------------------------------------------------------------------------------------------
function DisplayStat:OnWindowMoveMain( wndHandler, wndControl, nOldLeft, nOldTop, nOldRight, nOldBottom )
 	self.Config.PositionMain = self:GetPosition(self.MainForm)
end

------------------------------------------------------------------------------------------------------
-- DisplayStat OnWindowSizeChangedMain
-- Saves the position after resize window in config data and change the size of the middle column.
------------------------------------------------------------------------------------------------------
function DisplayStat:OnWindowSizeChangedMain( wndHandler, wndControl )
 	self.Config.PositionMain = self:GetPosition(self.MainForm)
end



------------------------------------------------------------------------------------------------------
-- DisplayStat GetPosition
-- Returns the position of the form as table.
------------------------------------------------------------------------------------------------------
function DisplayStat:GetPosition(form)
 	local result = nil
 	if form ~= nil then
  		local leftAnchor, topAnchor, rightAnchor, bottomAnchor = form:GetAnchorOffsets()
  		result =
  		{
   		Bottom = bottomAnchor,
   		Left = leftAnchor,
   		Right = rightAnchor,
   		Top = topAnchor,
  		}
 	end
 	return result
end


------------------------------------------------------------------------------------------------------
-- DisplayStat MainShow
-- Open the main form and do preparations.
------------------------------------------------------------------------------------------------------
function DisplayStat:MainShow()
 	-- Set config that main view is visible.
 	self.Config.IsVisible = true
 	self.MainForm:Show(true, false)
end


------------------------------------------------------------------------------------------------------
-- DisplayStat MainHide
-- Close the main form and deregister events.
------------------------------------------------------------------------------------------------------
function DisplayStat:MainHide()
 	-- Set config that main view is not visible.
 	self.Config.IsVisible = false
 	self.MainForm:Show(false, false)
end



---------------------------------------------------------------------------------------------------
-- OnConfigure
---------------------------------------------------------------------------------------------------

function DisplayStat:OnConfigure( wndHandler, wndControl, eMouseButton )
	self.ConfigForm:Show(true, false)
	self:MatchWithConfig()
	self:MatchWithCustomName()
end


---------------------------------------------------------------------------------------------------
-- OnConfigClose
---------------------------------------------------------------------------------------------------
function DisplayStat:OnConfigClose( wndHandler, wndControl, eMouseButton )
	self.ConfigForm:Show(false, false)
end

---------------------------------------------------------------------------------------------------
-- OnWindowMoveConfig
---------------------------------------------------------------------------------------------------
function DisplayStat:OnWindowMoveConfig( wndHandler, wndControl, nOldLeft, nOldTop, nOldRight, nOldBottom )
	self.Config.PositionConfig = self:GetPosition(self.ConfigForm)
end



------------------------------------------------------------------------------------------------------
-- OnCustomName
------------------------------------------------------------------------------------------------------

function DisplayStat:OnCustomNameWindowCheck( wndHandler, wndControl, eMouseButton )
	self.ConfigForm:FindChild("CustomNameWindow"):Show(true, false)
	self:MatchWithCustomName()
end

function DisplayStat:OnCustomNameWindowUnCheck( wndHandler, wndControl, eMouseButton )
	self.ConfigForm:FindChild("CustomNameWindow"):Show(false, true)
end


function DisplayStat:OnCustomNameCheck( wndHandler, wndControl, eMouseButton )
	self.Config.IsCustomNameChecked = true
end

function DisplayStat:OnCustomNameUnCheck( wndHandler, wndControl, eMouseButton )
	self.Config.IsCustomNameChecked = false
end


function DisplayStat:OnResetCustomName( wndHandler, wndControl, eMouseButton )
	local customNameWnd = self.ConfigForm:FindChild("CustomNameWindow"):FindChild("CustomNameContainer")
	customNameWnd:FindChild("MaxHealthEditBox"):SetText("MaxHP")
	customNameWnd:FindChild("MaxShieldEditBox"):SetText("MaxShield")
	customNameWnd:FindChild("AssaultPowerEditBox"):SetText("AP")
	customNameWnd:FindChild("SupportPowerEditBox"):SetText("SP")
	customNameWnd:FindChild("ArmorEditBox"):SetText("Armor")
	customNameWnd:FindChild("StrikethroughEditBox"):SetText("Hit")
	customNameWnd:FindChild("CriticalChanceEditBox"):SetText("Crit")
	customNameWnd:FindChild("CriticalSeverityEditBox"):SetText("CritSev")
	customNameWnd:FindChild("LifestealEditBox"):SetText("Lifesteal")
	customNameWnd:FindChild("ArmorPenEditBox"):SetText("ArmorPen")
	customNameWnd:FindChild("ShieldPenEditBox"):SetText("ShieldPen")
	customNameWnd:FindChild("PhysicalResEditBox"):SetText("PhysRes")
	customNameWnd:FindChild("TechResEditBox"):SetText("TechRes")
	customNameWnd:FindChild("MagicResEditBox"):SetText("MagicRes")
	customNameWnd:FindChild("DeflectEditBox"):SetText("Deflect")
	customNameWnd:FindChild("DeflectCritEditBox"):SetText("DeflectCrit")
	customNameWnd:FindChild("CCDurationEditBox"):SetText("CCRed")
	customNameWnd:FindChild("CooldownReductionEditBox"):SetText("CDRed")
	customNameWnd:FindChild("ManaRecoveryEditBox"):SetText("FocusRegen")
	customNameWnd:FindChild("ManaCostRedEditBox"):SetText("FocusCostRed")
	customNameWnd:FindChild("ShieldRebootEditBox"):SetText("ShieldReboot")
	customNameWnd:FindChild("ShieldRegenPercentEditBox"):SetText("ShieldRegen")
	--customNameWnd:FindChild("PvPOffenseEditBox"):SetText("PvPAtk")
	--customNameWnd:FindChild("PvPHealEditBox"):SetText("PvPHeal")
	--customNameWnd:FindChild("PvPDefEditBox"):SetText("PvPDef")

end

function DisplayStat:OnApplyCustomName( wndHandler, wndControl, eMouseButton )
	local customNameWnd = self.ConfigForm:FindChild("CustomNameWindow"):FindChild("CustomNameContainer")
	self.Config.Attribute.MaxHealth.customName = customNameWnd:FindChild("MaxHealthEditBox"):GetText()
	self.Config.Attribute.MaxShield.customName = customNameWnd:FindChild("MaxShieldEditBox"):GetText()
	self.Config.Attribute.AssaultPower.customName = customNameWnd:FindChild("AssaultPowerEditBox"):GetText()
	self.Config.Attribute.SupportPower.customName = customNameWnd:FindChild("SupportPowerEditBox"):GetText()
	self.Config.Attribute.Armor.customName = customNameWnd:FindChild("ArmorEditBox"):GetText()
	self.Config.Attribute.Strikethrough.customName = customNameWnd:FindChild("StrikethroughEditBox"):GetText()
	self.Config.Attribute.CritChance.customName = customNameWnd:FindChild("CriticalChanceEditBox"):GetText()
	self.Config.Attribute.CritSeverity.customName = customNameWnd:FindChild("CriticalSeverityEditBox"):GetText()
	self.Config.Attribute.Lifesteal.customName = customNameWnd:FindChild("LifestealEditBox"):GetText()
	self.Config.Attribute.ArmorPen.customName = customNameWnd:FindChild("ArmorPenEditBox"):GetText()
	self.Config.Attribute.ShieldPen.customName = customNameWnd:FindChild("ShieldPenEditBox"):GetText()
	self.Config.Attribute.PhysicalMit.customName = customNameWnd:FindChild("PhysicalResEditBox"):GetText()
	self.Config.Attribute.TechMit.customName = customNameWnd:FindChild("TechResEditBox"):GetText()
	self.Config.Attribute.MagicMit.customName = customNameWnd:FindChild("MagicResEditBox"):GetText()
	self.Config.Attribute.Deflect.customName = customNameWnd:FindChild("DeflectEditBox"):GetText()
	self.Config.Attribute.DeflectCrit.customName = customNameWnd:FindChild("DeflectCritEditBox"):GetText()
	self.Config.Attribute.CCDuration.customName = customNameWnd:FindChild("CCDurationEditBox"):GetText()
	self.Config.Attribute.CooldownReduction.customName = customNameWnd:FindChild("CooldownReductionEditBox"):GetText()
	self.Config.Attribute.ManaRecovery.customName = customNameWnd:FindChild("ManaRecoveryEditBox"):GetText()
	self.Config.Attribute.ManaCostRed.customName = customNameWnd:FindChild("ManaCostRedEditBox"):GetText()
	self.Config.Attribute.ShieldReboot.customName = customNameWnd:FindChild("ShieldRebootEditBox"):GetText()
	self.Config.Attribute.ShieldRegenPercent.customName = customNameWnd:FindChild("ShieldRegenPercentEditBox"):GetText()
	--self.Config.Attribute.PvPOffense.customName = customNameWnd:FindChild("PvPOffenseEditBox"):GetText()
	--self.Config.Attribute.PvPHeal.customName = customNameWnd:FindChild("PvPHealEditBox"):GetText()
	--self.Config.Attribute.PvPDef.customName = customNameWnd:FindChild("PvPDefEditBox"):GetText()
	
	self:MatchWithConfig()
end

function DisplayStat:IsCustomName(attribute)
	if self.Config.IsCustomNameChecked == true then
		return attribute.customName
	else
		return attribute.name
	end
end

------------------------------------------------------------------------------------------------------
-- OnMainTimer
------------------------------------------------------------------------------------------------------
function DisplayStat:OnMainTimer()
	self:UpdateStats()

end
------------------------------------------------------------------------------------------------------
-- Update Stats
------------------------------------------------------------------------------------------------------
function DisplayStat:UpdateStats()
	local player = GameLib.GetPlayerUnit()
	if player ~= nil then
	local actAttribute = 
	{
		MaxHealth = math.ceil(player:GetMaxHealth()),
		MaxShield = math.ceil(player:GetShieldCapacityMax()),
		AssaultPower = math.floor(player:GetAssaultPower()),
		SupportPower = math.floor(player:GetSupportPower()),
		Armor = math.floor(player:GetUnitProperties().Armor.fValue),
		Strikethrough = String_GetWeaselString(Apollo.GetString("Character_PercentAppendLabel"), Apollo.FormatNumber(math.floor((player:GetStrikethroughChance() + 0.000005) * 10000) / 100, 2, true)),
		CritChance = String_GetWeaselString(Apollo.GetString("Character_PercentAppendLabel"), Apollo.FormatNumber(math.floor((player:GetCritChance() + 0.000005) * 10000) / 100, 2, true)),
		CritSeverity = String_GetWeaselString(Apollo.GetString("Character_PercentAppendLabel"), Apollo.FormatNumber(math.floor((player:GetCritSeverity() + 0.000005) * 10000) / 100, 2, true)),
		ArmorPen = String_GetWeaselString(Apollo.GetString("Character_PercentAppendLabel"), Apollo.FormatNumber(math.floor((player:GetIgnoreArmorBase() + 0.000005) * 10000) / 100, 2, true)),
		ShieldPen = String_GetWeaselString(Apollo.GetString("Character_PercentAppendLabel"), Apollo.FormatNumber(math.floor((player:GetIgnoreShieldBase() + 0.000005) * 10000) / 100, 2, true)),
		Lifesteal = String_GetWeaselString(Apollo.GetString("Character_PercentAppendLabel"), Apollo.FormatNumber(math.floor((player:GetBaseLifesteal() + 0.000005) * 10000) / 100, 2, true)),
		CooldownReduction = String_GetWeaselString(Apollo.GetString("Character_PercentAppendLabel"), Apollo.FormatNumber(-1 * math.floor((player:GetCooldownReductionModifier() + 0.000005 - 1) * 10000) / 100, 2, true)),
		ShieldRegenPercent = String_GetWeaselString(Apollo.GetString("Character_PercentAppendLabel"), Apollo.FormatNumber(math.floor((player:GetShieldRegenPct() + 0.000005) * 10000) / 100, 2, true)),
		ShieldReboot = String_GetWeaselString(Apollo.GetString("Character_SecondsLabel"), Apollo.FormatNumber(player:GetShieldRebootTime() / 1000, 2, true)),
		PhysicalMit = String_GetWeaselString(Apollo.GetString("Character_PercentAppendLabel"), Apollo.FormatNumber(math.floor((player:GetPhysicalMitigation() + 0.000005) * 10000) / 100, 2, true)),
		TechMit = String_GetWeaselString(Apollo.GetString("Character_PercentAppendLabel"), Apollo.FormatNumber(math.floor((player:GetTechMitigation() + 0.000005) * 10000) / 100, 2, true)),
		MagicMit = String_GetWeaselString(Apollo.GetString("Character_PercentAppendLabel"), Apollo.FormatNumber(math.floor((player:GetMagicMitigation() + 0.000005) * 10000) / 100, 2, true)),
		Deflect = String_GetWeaselString(Apollo.GetString("Character_PercentAppendLabel"), Apollo.FormatNumber(math.floor((player:GetDeflectChance() + 0.000005) * 10000) / 100, 2, true)),
		DeflectCrit = String_GetWeaselString(Apollo.GetString("Character_PercentAppendLabel"), Apollo.FormatNumber(math.floor((player:GetDeflectCritChance() + 0.000005) * 10000) / 100, 2, true)),
		CCDuration = String_GetWeaselString(Apollo.GetString("Character_PercentAppendLabel"), Apollo.FormatNumber(math.floor((math.abs(player:GetCCDurationModifier() -1) + 0.000005) * 10000) / 100, 2, true)),
		ManaRecovery = String_GetWeaselString(Apollo.GetString("Character_PerSecLabel"), Apollo.FormatNumber(player:GetManaRegenInCombat() * 2, 2, true)),
		ManaCostRed = String_GetWeaselString(Apollo.GetString("Character_PercentAppendLabel"), Apollo.FormatNumber(math.floor((math.abs(player:GetManaCostModifier() -1) + 0.000005) * 10000) / 100, 2, true)),
		PvPOffense = String_GetWeaselString(Apollo.GetString("Character_PercentAppendLabel"), Apollo.FormatNumber(math.floor((player:GetPvPDamageI() + 0.000005) * 10000) / 100, 2, true)),
		PvPHeal = String_GetWeaselString(Apollo.GetString("Character_PercentAppendLabel"), Apollo.FormatNumber(math.floor((player:GetPvPHealingI() + 0.000005) * 10000) / 100, 2, true)),
		PvPDef = String_GetWeaselString(Apollo.GetString("Character_PercentAppendLabel"), Apollo.FormatNumber(math.floor((1 - player:GetPvPDefenseI() + 0.000005) * 10000) / 100, 2, true))	}
		for index, child in pairs(self.MainForm:FindChild("AttributeFraming"):GetChildren()) do
			
			if child:FindChild("AttributeName"):GetText() == self:IsCustomName(self.Config.Attribute.MaxHealth) then
				child:FindChild("AttributeValue"):SetText(actAttribute.MaxHealth)
			end
			
			if child:FindChild("AttributeName"):GetText() == self:IsCustomName(self.Config.Attribute.MaxShield) then
				child:FindChild("AttributeValue"):SetText(actAttribute.MaxShield)
			end
			
			if child:FindChild("AttributeName"):GetText() == self:IsCustomName(self.Config.Attribute.AssaultPower) then
				child:FindChild("AttributeValue"):SetText(actAttribute.AssaultPower)
			end
			
			if child:FindChild("AttributeName"):GetText() == self:IsCustomName(self.Config.Attribute.SupportPower) then
				child:FindChild("AttributeValue"):SetText(actAttribute.SupportPower)
			end
			
			if child:FindChild("AttributeName"):GetText() == self:IsCustomName(self.Config.Attribute.Armor) then
				child:FindChild("AttributeValue"):SetText(actAttribute.Armor)
			end
			
			if child:FindChild("AttributeName"):GetText() == self:IsCustomName(self.Config.Attribute.Strikethrough) then
				child:FindChild("AttributeValue"):SetText(actAttribute.Strikethrough)
			end
			
			if child:FindChild("AttributeName"):GetText() == self:IsCustomName(self.Config.Attribute.CritChance) then
				child:FindChild("AttributeValue"):SetText(actAttribute.CritChance)
			end
			
			if child:FindChild("AttributeName"):GetText() == self:IsCustomName(self.Config.Attribute.CritSeverity) then
				child:FindChild("AttributeValue"):SetText(actAttribute.CritSeverity)
			end
			
			if child:FindChild("AttributeName"):GetText() == self:IsCustomName(self.Config.Attribute.ArmorPen) then
				child:FindChild("AttributeValue"):SetText(actAttribute.ArmorPen)
			end
			
			if child:FindChild("AttributeName"):GetText() == self:IsCustomName(self.Config.Attribute.ShieldPen) then
				child:FindChild("AttributeValue"):SetText(actAttribute.ShieldPen)
			end
		
			if child:FindChild("AttributeName"):GetText() == self:IsCustomName(self.Config.Attribute.Lifesteal) then
				child:FindChild("AttributeValue"):SetText(actAttribute.Lifesteal)
			end
			
			if child:FindChild("AttributeName"):GetText() == self:IsCustomName(self.Config.Attribute.CooldownReduction) then
				child:FindChild("AttributeValue"):SetText(actAttribute.CooldownReduction)
			end
			
			if child:FindChild("AttributeName"):GetText() == self:IsCustomName(self.Config.Attribute.ShieldRegenPercent) then
				child:FindChild("AttributeValue"):SetText(actAttribute.ShieldRegenPercent)
			end
			
			if child:FindChild("AttributeName"):GetText() == self:IsCustomName(self.Config.Attribute.ShieldReboot) then
				child:FindChild("AttributeValue"):SetText(actAttribute.ShieldReboot)
			end
			
			if child:FindChild("AttributeName"):GetText() == self:IsCustomName(self.Config.Attribute.PhysicalMit) then
				child:FindChild("AttributeValue"):SetText(actAttribute.PhysicalMit)
			end
			
			if child:FindChild("AttributeName"):GetText() == self:IsCustomName(self.Config.Attribute.TechMit) then
				child:FindChild("AttributeValue"):SetText(actAttribute.TechMit)
			end
			
			if child:FindChild("AttributeName"):GetText() == self:IsCustomName(self.Config.Attribute.MagicMit) then
				child:FindChild("AttributeValue"):SetText(actAttribute.MagicMit)
			end

			if child:FindChild("AttributeName"):GetText() == self:IsCustomName(self.Config.Attribute.Deflect) then
				child:FindChild("AttributeValue"):SetText(actAttribute.Deflect)
			end
			
			if child:FindChild("AttributeName"):GetText() == self:IsCustomName(self.Config.Attribute.DeflectCrit) then
				child:FindChild("AttributeValue"):SetText(actAttribute.DeflectCrit)
			end
			
			if child:FindChild("AttributeName"):GetText() == self:IsCustomName(self.Config.Attribute.CCDuration) then
				child:FindChild("AttributeValue"):SetText(actAttribute.CCDuration)
			end

			if child:FindChild("AttributeName"):GetText() == self:IsCustomName(self.Config.Attribute.ManaRecovery) then
				child:FindChild("AttributeValue"):SetText(actAttribute.ManaRecovery)
			end

			if child:FindChild("AttributeName"):GetText() == self:IsCustomName(self.Config.Attribute.ManaCostRed) then
				child:FindChild("AttributeValue"):SetText(actAttribute.ManaCostRed)
			end

			--[[if child:FindChild("AttributeName"):GetText() == self:IsCustomName(self.Config.Attribute.PvPOffense) then
				child:FindChild("AttributeValue"):SetText(actAttribute.PvPOffensePercent)
			end

			if child:FindChild("AttributeName"):GetText() == self:IsCustomName(self.Config.Attribute.PvPHeal) then
				child:FindChild("AttributeValue"):SetText(actAttribute.PvPOffenseRating)
			end

			if child:FindChild("AttributeName"):GetText() == self:IsCustomName(self.Config.Attribute.PvPDef) then
				child:FindChild("AttributeValue"):SetText(actAttribute.PvPDefPercent)
			end]]

		end
	
	end
	
end

---------------------------------------------------------------------------------------------------
-- AttributeContainers
---------------------------------------------------------------------------------------------------

function DisplayStat:NewAttributeContainer(attribute)
	local child = Apollo.LoadForm(cXmlDoc, "AttributeContainer", self.MainForm:FindChild("AttributeFraming"), self)
	if self.Config.IsCustomNameChecked == true then
		child:FindChild("AttributeName"):SetText(attribute.customName)
	else
		child:FindChild("AttributeName"):SetText(attribute.name)
	end
	self.MainForm:FindChild("AttributeFraming"):ArrangeChildrenVert()
end

function DisplayStat:DestroyAttributeContainer(attribute)
	for index, child in pairs(self.MainForm:FindChild("AttributeFraming"):GetChildren()) do
		if child:FindChild("AttributeName"):GetText() == self:IsCustomName(attribute) then
			child:Destroy()
		end
	end
	self.MainForm:FindChild("AttributeFraming"):ArrangeChildrenVert()
end
---------------------------------------------------------------------------------------------------
-- MatchWithConfig
---------------------------------------------------------------------------------------------------

function DisplayStat:MatchWithConfig()
	self.ConfigForm:FindChild("chMaxHealth"):SetCheck(self.Config.bMaxHealth)
	self.ConfigForm:FindChild("chMaxShield"):SetCheck(self.Config.bMaxShield)
	self.ConfigForm:FindChild("chAssaultPower"):SetCheck(self.Config.bAssaultPower)
	self.ConfigForm:FindChild("chSupportPower"):SetCheck(self.Config.bSupportPower)
	self.ConfigForm:FindChild("chArmor"):SetCheck(self.Config.bArmor)
	self.ConfigForm:FindChild("chStrikethrough"):SetCheck(self.Config.bStrikethrough)
	self.ConfigForm:FindChild("chCritChance"):SetCheck(self.Config.bCritChance)
	self.ConfigForm:FindChild("chCritSeverity"):SetCheck(self.Config.bCritSeverity)
	self.ConfigForm:FindChild("chArmorPen"):SetCheck(self.Config.bArmorPen)
	self.ConfigForm:FindChild("chShieldPen"):SetCheck(self.Config.bShieldPen)
	self.ConfigForm:FindChild("chLifesteal"):SetCheck(self.Config.bLifesteal)
	self.ConfigForm:FindChild("chCooldownReduction"):SetCheck(self.Config.bCooldownReduction)
	self.ConfigForm:FindChild("chShieldRegenPercent"):SetCheck(self.Config.bShieldRegenPercent)
	self.ConfigForm:FindChild("chShieldReboot"):SetCheck(self.Config.bShieldReboot)
	self.ConfigForm:FindChild("chPhysicalMit"):SetCheck(self.Config.bPhysicalMit)
	self.ConfigForm:FindChild("chTechMit"):SetCheck(self.Config.bTechMit)
	self.ConfigForm:FindChild("chMagicMit"):SetCheck(self.Config.bMagicMit)
	self.ConfigForm:FindChild("chDeflect"):SetCheck(self.Config.bDeflect)
	self.ConfigForm:FindChild("chDeflectCrit"):SetCheck(self.Config.bDeflectCrit)
	self.ConfigForm:FindChild("chCCDuration"):SetCheck(self.Config.bCCDuration)
	self.ConfigForm:FindChild("chManaRecovery"):SetCheck(self.Config.bManaRecovery)
	self.ConfigForm:FindChild("chManaCostRed"):SetCheck(self.Config.bManaCostRed)
	--self.ConfigForm:FindChild("chPvPOffense"):SetCheck(self.Config.bPvPOffense)
	--self.ConfigForm:FindChild("chPvPHeal"):SetCheck(self.Config.bPvPHeal)
	--self.ConfigForm:FindChild("chPvPDef"):SetCheck(self.Config.bPvPDef)
	
	self.MainForm:FindChild("AttributeFraming"):DestroyChildren()
	
	if self.Config.bMaxHealth == true then 			self:NewAttributeContainer(self.Config.Attribute.MaxHealth) end
	if self.Config.bMaxShield == true then 			self:NewAttributeContainer(self.Config.Attribute.MaxShield) end
	if self.Config.bAssaultPower == true then 		self:NewAttributeContainer(self.Config.Attribute.AssaultPower) end
	if self.Config.bSupportPower == true then 		self:NewAttributeContainer(self.Config.Attribute.SupportPower) end
	if self.Config.bArmor == true then 				self:NewAttributeContainer(self.Config.Attribute.Armor) end
	if self.Config.bStrikethrough == true then 		self:NewAttributeContainer(self.Config.Attribute.Strikethrough) end
	if self.Config.bCritChance == true then 		self:NewAttributeContainer(self.Config.Attribute.CritChance) end
	if self.Config.bCritSeverity == true then 		self:NewAttributeContainer(self.Config.Attribute.CritSeverity) end
	if self.Config.bArmorPen == true then 			self:NewAttributeContainer(self.Config.Attribute.ArmorPen) end
	if self.Config.bShieldPen == true then 			self:NewAttributeContainer(self.Config.Attribute.ShieldPen) end
	if self.Config.bLifesteal == true then 			self:NewAttributeContainer(self.Config.Attribute.Lifesteal) end
	if self.Config.bCooldownReduction == true then 	self:NewAttributeContainer(self.Config.Attribute.CooldownReduction) end
	if self.Config.bShieldRegenPercent == true then self:NewAttributeContainer(self.Config.Attribute.ShieldRegenPercent) end
	if self.Config.bShieldReboot == true then 		self:NewAttributeContainer(self.Config.Attribute.ShieldReboot) end
	if self.Config.bPhysicalMit == true then 		self:NewAttributeContainer(self.Config.Attribute.PhysicalMit) end
	if self.Config.bTechMit == true then  			self:NewAttributeContainer(self.Config.Attribute.TechMit) end
	if self.Config.bMagicMit == true then 			self:NewAttributeContainer(self.Config.Attribute.MagicMit) end
	if self.Config.bDeflect == true then 			self:NewAttributeContainer(self.Config.Attribute.Deflect) end
	if self.Config.bDeflectCrit == true then 		self:NewAttributeContainer(self.Config.Attribute.DeflectCrit) end
	if self.Config.bCCDuration == true then 		self:NewAttributeContainer(self.Config.Attribute.CCDuration) end
	if self.Config.bManaRecovery == true then 		self:NewAttributeContainer(self.Config.Attribute.ManaRecovery) end
	if self.Config.bManaCostRed == true then 		self:NewAttributeContainer(self.Config.Attribute.ManaCostRed) end
	--if self.Config.bPvPOffense == true then 		self:NewAttributeContainer(self.Config.Attribute.PvPOffense) end
	--if self.Config.bPvPHeal == true then 			self:NewAttributeContainer(self.Config.Attribute.PvPHeal) end
	--if self.Config.bPvPDef == true then 			self:NewAttributeContainer(self.Config.Attribute.PvPDef) end

	
	if self.Config.IsCustomNameChecked == true then
	
		self.ConfigForm:FindChild("CustomNameWindow"):FindChild("chCustomName"):SetCheck(true)
	
		for index, child in pairs(self.MainForm:FindChild("AttributeFraming"):GetChildren()) do
			
			if child:FindChild("AttributeName"):GetText() == self:IsCustomName(self.Config.Attribute.MaxHealth) then
				child:FindChild("AttributeName"):SetText(self.Config.Attribute.MaxHealth.customName)
			end
			
			if child:FindChild("AttributeName"):GetText() == self:IsCustomName(self.Config.Attribute.MaxShield) then
				child:FindChild("AttributeName"):SetText(self.Config.Attribute.MaxShield.customName)
			end
			
			if child:FindChild("AttributeName"):GetText() == self:IsCustomName(self.Config.Attribute.AssaultPower) then
				child:FindChild("AttributeName"):SetText(self.Config.Attribute.AssaultPower.customName)
			end
			
			if child:FindChild("AttributeName"):GetText() == self:IsCustomName(self.Config.Attribute.SupportPower) then
				child:FindChild("AttributeName"):SetText(self.Config.Attribute.SupportPower.customName)
			end
			
			if child:FindChild("AttributeName"):GetText() == self:IsCustomName(self.Config.Attribute.Armor) then
				child:FindChild("AttributeName"):SetText(self.Config.Attribute.Armor.customName)
			end
			
			if child:FindChild("AttributeName"):GetText() == self:IsCustomName(self.Config.Attribute.Strikethrough) then
				child:FindChild("AttributeName"):SetText(self.Config.Attribute.Strikethrough.customName)
			end
			
			if child:FindChild("AttributeName"):GetText() == self:IsCustomName(self.Config.Attribute.CritChance) then
				child:FindChild("AttributeName"):SetText(self.Config.Attribute.CritChance.customName)
			end
			
			if child:FindChild("AttributeName"):GetText() == self:IsCustomName(self.Config.Attribute.CritSeverity) then
				child:FindChild("AttributeName"):SetText(self.Config.Attribute.CritSeverity.customName)
			end
			
			if child:FindChild("AttributeName"):GetText() == self:IsCustomName(self.Config.Attribute.ArmorPen) then
				child:FindChild("AttributeName"):SetText(self.Config.Attribute.ArmorPen.customName)
			end
			
			if child:FindChild("AttributeName"):GetText() == self:IsCustomName(self.Config.Attribute.ShieldPen) then
				child:FindChild("AttributeName"):SetText(self.Config.Attribute.ShieldPen.customName)
			end
		
			if child:FindChild("AttributeName"):GetText() == self:IsCustomName(self.Config.Attribute.Lifesteal) then
				child:FindChild("AttributeName"):SetText(self.Config.Attribute.Lifesteal.customName)
			end
			
			if child:FindChild("AttributeName"):GetText() == self:IsCustomName(self.Config.Attribute.CooldownReduction) then
				child:FindChild("AttributeName"):SetText(self.Config.Attribute.CooldownReduction.customName)
			end
			
			if child:FindChild("AttributeName"):GetText() == self:IsCustomName(self.Config.Attribute.ShieldRegenPercent) then
				child:FindChild("AttributeName"):SetText(self.Config.Attribute.ShieldRegenPercent.customName)
			end
			
			if child:FindChild("AttributeName"):GetText() == self:IsCustomName(self.Config.Attribute.ShieldReboot) then
				child:FindChild("AttributeName"):SetText(self.Config.Attribute.ShieldReboot.customName)
			end
			
			if child:FindChild("AttributeName"):GetText() == self:IsCustomName(self.Config.Attribute.PhysicalMit) then
				child:FindChild("AttributeName"):SetText(self.Config.Attribute.PhysicalMit.customName)
			end
			
			if child:FindChild("AttributeName"):GetText() == self:IsCustomName(self.Config.Attribute.TechMit) then
				child:FindChild("AttributeName"):SetText(self.Config.Attribute.TechMit.customName)
			end
			
			if child:FindChild("AttributeName"):GetText() == self:IsCustomName(self.Config.Attribute.MagicMit) then
				child:FindChild("AttributeName"):SetText(self.Config.Attribute.MagicMit.customName)
			end

			if child:FindChild("AttributeName"):GetText() == self:IsCustomName(self.Config.Attribute.Deflect) then
				child:FindChild("AttributeName"):SetText(self.Config.Attribute.Deflect.customName)
			end
			
			if child:FindChild("AttributeName"):GetText() == self:IsCustomName(self.Config.Attribute.DeflectCrit) then
				child:FindChild("AttributeName"):SetText(self.Config.Attribute.DeflectCrit.customName)
			end
			
			if child:FindChild("AttributeName"):GetText() == self:IsCustomName(self.Config.Attribute.CCDuration) then
				child:FindChild("AttributeName"):SetText(self.Config.Attribute.CCDuration.customName)
			end

			if child:FindChild("AttributeName"):GetText() == self:IsCustomName(self.Config.Attribute.ManaRecovery) then
				child:FindChild("AttributeName"):SetText(self.Config.Attribute.ManaRecovery.customName)
			end

			if child:FindChild("AttributeName"):GetText() == self:IsCustomName(self.Config.Attribute.ManaCostRed) then
				child:FindChild("AttributeName"):SetText(self.Config.Attribute.ManaCostRed.customName)
			end

			--[[if child:FindChild("AttributeName"):GetText() == self:IsCustomName(self.Config.Attribute.PvPOffense) then
				child:FindChild("AttributeName"):SetText(self.Config.Attribute.PvPOffense.customName)
			end

			if child:FindChild("AttributeName"):GetText() == self:IsCustomName(self.Config.Attribute.PvPHeal) then
				child:FindChild("AttributeName"):SetText(self.Config.Attribute.PvPHeal.customName)
			end

			if child:FindChild("AttributeName"):GetText() == self:IsCustomName(self.Config.Attribute.PvPDef) then
				child:FindChild("AttributeName"):SetText(self.Config.Attribute.PvPDef.customName)
			end]]


		end
		
	end
	
	if self.Config.IsCustomNameChecked == false then
	
		self.ConfigForm:FindChild("CustomNameWindow"):FindChild("chCustomName"):SetCheck(false)	
	
		for index, child in pairs(self.MainForm:FindChild("AttributeFraming"):GetChildren()) do
			
			if child:FindChild("AttributeName"):GetText() == self.Config.Attribute.MaxHealth.customName then
				child:FindChild("AttributeName"):SetText(self.Config.Attribute.MaxHealth.name)
			end
			
			if child:FindChild("AttributeName"):GetText() == self.Config.Attribute.MaxShield.customName then
				child:FindChild("AttributeName"):SetText(self.Config.Attribute.MaxShield.name)
			end
			
			if child:FindChild("AttributeName"):GetText() == self.Config.Attribute.AssaultPower.customName then
				child:FindChild("AttributeName"):SetText(self.Config.Attribute.AssaultPower.name)
			end
			
			if child:FindChild("AttributeName"):GetText() == self.Config.Attribute.SupportPower.customName then
				child:FindChild("AttributeName"):SetText(self.Config.Attribute.SupportPower.name)
			end
			
			if child:FindChild("AttributeName"):GetText() == self.Config.Attribute.Armor.customName then
				child:FindChild("AttributeName"):SetText(self.Config.Attribute.Armor.name)
			end
			
			if child:FindChild("AttributeName"):GetText() == self.Config.Attribute.Strikethrough.customName then
				child:FindChild("AttributeName"):SetText(self.Config.Attribute.Strikethrough.name)
			end
			
			if child:FindChild("AttributeName"):GetText() == self.Config.Attribute.CritChance.customName then
				child:FindChild("AttributeName"):SetText(self.Config.Attribute.CritChance.name)
			end
			
			if child:FindChild("AttributeName"):GetText() == self.Config.Attribute.CritSeverity.customName then
				child:FindChild("AttributeName"):SetText(self.Config.Attribute.CritSeverity.name)
			end
			
			if child:FindChild("AttributeName"):GetText() == self.Config.Attribute.ArmorPen.customName then
				child:FindChild("AttributeName"):SetText(self.Config.Attribute.ArmorPen.name)
			end
			
			if child:FindChild("AttributeName"):GetText() == self.Config.Attribute.ShieldPen.customName then
				child:FindChild("AttributeName"):SetText(self.Config.Attribute.ShieldPen.name)
			end
		
			if child:FindChild("AttributeName"):GetText() == self.Config.Attribute.Lifesteal.customName then
				child:FindChild("AttributeName"):SetText(self.Config.Attribute.Lifesteal.name)
			end
			
			if child:FindChild("AttributeName"):GetText() == self.Config.Attribute.CooldownReduction.customName then
				child:FindChild("AttributeName"):SetText(self.Config.Attribute.CooldownReduction.name)
			end
			
			if child:FindChild("AttributeName"):GetText() == self.Config.Attribute.ShieldRegenPercent.customName then
				child:FindChild("AttributeName"):SetText(self.Config.Attribute.ShieldRegenPercent.name)
			end
			
			if child:FindChild("AttributeName"):GetText() == self.Config.Attribute.ShieldReboot.customName then
				child:FindChild("AttributeName"):SetText(self.Config.Attribute.ShieldReboot.name)
			end
			
			if child:FindChild("AttributeName"):GetText() == self.Config.Attribute.PhysicalMit.customName then
				child:FindChild("AttributeName"):SetText(self.Config.Attribute.PhysicalMit.name)
			end
			
			if child:FindChild("AttributeName"):GetText() == self.Config.Attribute.TechMit.customName then
				child:FindChild("AttributeName"):SetText(self.Config.Attribute.TechMit.name)
			end
			
			if child:FindChild("AttributeName"):GetText() == self.Config.Attribute.MagicMit.customName then
				child:FindChild("AttributeName"):SetText(self.Config.Attribute.MagicMit.name)
			end

			if child:FindChild("AttributeName"):GetText() == self.Config.Attribute.Deflect.customName then
				child:FindChild("AttributeName"):SetText(self.Config.Attribute.Deflect.name)
			end
			
			if child:FindChild("AttributeName"):GetText() == self.Config.Attribute.DeflectCrit.customName then
				child:FindChild("AttributeName"):SetText(self.Config.Attribute.DeflectCrit.name)
			end
			
			if child:FindChild("AttributeName"):GetText() == self.Config.Attribute.CCDuration.customName then
				child:FindChild("AttributeName"):SetText(self.Config.Attribute.CCDuration.name)
			end

			if child:FindChild("AttributeName"):GetText() == self.Config.Attribute.ManaRecovery.customName then
				child:FindChild("AttributeName"):SetText(self.Config.Attribute.ManaRecovery.name)
			end

			if child:FindChild("AttributeName"):GetText() == self.Config.Attribute.ManaCostRed.customName then
				child:FindChild("AttributeName"):SetText(self.Config.Attribute.ManaCostRed.name)
			end

			--[[if child:FindChild("AttributeName"):GetText() == self.Config.Attribute.PvPOffense.customName then
				child:FindChild("AttributeName"):SetText(self.Config.Attribute.PvPOffense.name)
			end

			if child:FindChild("AttributeName"):GetText() == self.Config.Attribute.PvPHeal.customName then
				child:FindChild("AttributeName"):SetText(self.Config.Attribute.PvPHeal.name)
			end

			if child:FindChild("AttributeName"):GetText() == self.Config.Attribute.PvPDef.customName then
				child:FindChild("AttributeName"):SetText(self.Config.Attribute.PvPDef.name)
			end]]

		end
		
	end

	
end


function DisplayStat:MatchWithCustomName()

	
	local customNameWnd = self.ConfigForm:FindChild("CustomNameWindow"):FindChild("CustomNameContainer")
	customNameWnd:FindChild("MaxHealthEditBox"):SetText(self.Config.Attribute.MaxHealth.customName)
	customNameWnd:FindChild("MaxShieldEditBox"):SetText(self.Config.Attribute.MaxShield.customName)
	customNameWnd:FindChild("AssaultPowerEditBox"):SetText(self.Config.Attribute.AssaultPower.customName)
	customNameWnd:FindChild("SupportPowerEditBox"):SetText(self.Config.Attribute.SupportPower.customName)
	customNameWnd:FindChild("ArmorEditBox"):SetText(self.Config.Attribute.Armor.customName)
	customNameWnd:FindChild("StrikethroughEditBox"):SetText(self.Config.Attribute.Strikethrough.customName)
	customNameWnd:FindChild("CriticalChanceEditBox"):SetText(self.Config.Attribute.CritChance.customName)
	customNameWnd:FindChild("CriticalSeverityEditBox"):SetText(self.Config.Attribute.CritSeverity.customName)
	customNameWnd:FindChild("ArmorPenEditBox"):SetText(self.Config.Attribute.ArmorPen.customName)
	customNameWnd:FindChild("ShieldPenEditBox"):SetText(self.Config.Attribute.ShieldPen.customName)
	customNameWnd:FindChild("LifestealEditBox"):SetText(self.Config.Attribute.Lifesteal.customName)
	customNameWnd:FindChild("CooldownReductionEditBox"):SetText(self.Config.Attribute.CooldownReduction.customName)
	customNameWnd:FindChild("ShieldRegenPercentEditBox"):SetText(self.Config.Attribute.ShieldRegenPercent.customName)
	customNameWnd:FindChild("ShieldRebootEditBox"):SetText(self.Config.Attribute.ShieldReboot.customName)
	customNameWnd:FindChild("PhysicalResEditBox"):SetText(self.Config.Attribute.PhysicalMit.customName)
	customNameWnd:FindChild("TechResEditBox"):SetText(self.Config.Attribute.TechMit.customName)
	customNameWnd:FindChild("MagicResEditBox"):SetText(self.Config.Attribute.MagicMit.customName)
	customNameWnd:FindChild("DeflectEditBox"):SetText(self.Config.Attribute.Deflect.customName)
	customNameWnd:FindChild("DeflectCritEditBox"):SetText(self.Config.Attribute.DeflectCrit.customName)
	customNameWnd:FindChild("CCDurationEditBox"):SetText(self.Config.Attribute.CCDuration.customName)
	customNameWnd:FindChild("ManaRecoveryEditBox"):SetText(self.Config.Attribute.ManaRecovery.customName)
	customNameWnd:FindChild("ManaCostRedEditBox"):SetText(self.Config.Attribute.ManaCostRed.customName)
	--customNameWnd:FindChild("PvPOffenseEditBox"):SetText(self.Config.Attribute.PvPOffense.customName)
	--customNameWnd:FindChild("PvPHealEditBox"):SetText(self.Config.Attribute.PvPHeal.customName)
	--customNameWnd:FindChild("PvPDefEditBox"):SetText(self.Config.Attribute.PvPDef.customName)

end

------------------------------------------------------------------------------------------------------
-- Template Stuff
------------------------------------------------------------------------------------------------------


-- Button AddTemplate
function DisplayStat:OnAddTemplate( wndHandler, wndControl, eMouseButton )
	local addTemplateName = self.ConfigForm:FindChild("AddTemplateName")
	local templateList = self.ConfigForm:FindChild("TemplateListContainer")
	if addTemplateName:GetText() == "" then
		addTemplateName:SetText("/!\\ Choose a template name /!\\")
	else
		table.insert(self.Config.TemplateList, {	
			TemplateName = addTemplateName:GetText(),
			tMaxHealth = self.Config.bMaxHealth,
			tMaxShield = self.Config.bMaxShield,
			tAssaultPower = self.Config.bAssaultPower,
			tSupportPower = self.Config.bSupportPower,
			tArmor = self.Config.bArmor,
			tStrikethrough = self.Config.bStrikethrough,
			tCritChance = self.Config.bCritChance,
			tCritSeverity = self.Config.bCritSeverity,
			tArmorPen = self.Config.bArmorPen,
			tShieldPen = self.Config.bShieldPen,
			tLifesteal = self.Config.bLifesteal,
			tCooldownReduction = self.Config.bCooldownReduction,
			tShieldRegenPercent = self.Config.bShieldRegenPercent,
			tShieldReboot = self.Config.bShieldReboot,
			tPhysicalMit = self.Config.bPhysicalMit,
			tTechMit = self.Config.bTechMit,
			tMagicMit = self.Config.bMagicMit,
			tDeflect = self.Config.bDeflect,
			tDeflectCrit = self.Config.bDeflectCrit,
			tCCDuration = self.Config.bCCDuration,
			tManaRecovery = self.Config.bManaRecovery,
			tManaCostRed = self.Config.bManaCostRed,
			--tPvPOffense = self.Config.bPvPOffense,
			--tPvPHeal = self.Config.bPvPHeal,
			--tPvPDef = self.Config.bPvPDef

		 } )
		
		local i = 0
		for index in pairs(self.Config.TemplateList) do
			i = i + 1
		end
		local Template = Apollo.LoadForm(cXmlDoc, "SelectTemplateButton", self.ConfigForm:FindChild("TemplateListContainer"), self)
		Template:SetText(self.Config.TemplateList[i].TemplateName)
		Template:SetData(self.Config.TemplateList[i].TemplateName)
		self.ConfigForm:FindChild("TemplateListContainer"):ArrangeChildrenVert()

	end
end


-- Button DeleteTemplate
function DisplayStat:OnTemplateDeleted( wndHandler, wndControl, eMouseButton )
	if self.Config.TemplateList ~= nil then
			table.remove(self.Config.TemplateList, self.ConfigForm:FindChild("TemplateListContainer"):GetRadioSel("Template"))	
			self.ConfigForm:FindChild("TemplateListContainer"):DestroyChildren()
			for index in pairs(self.Config.TemplateList) do
				local Template = Apollo.LoadForm(cXmlDoc, "SelectTemplateButton", self.ConfigForm:FindChild("TemplateListContainer"), self)
				Template:SetText(self.Config.TemplateList[index].TemplateName)
				Template:SetData(self.Config.TemplateList[index].TemplateName)
			end
			self.ConfigForm:FindChild("TemplateListContainer"):ArrangeChildrenVert()
			self:UnCheckAllAttributes()

	else
		self.ConfigForm:FindChild("TemplateListContainer"):DestroyChildren()
		self.Config.TemplateSelected = nil
	end

end


-- Button ApplyAttributes
function DisplayStat:OnApplySelectedTemplate( wndHandler, wndControl, eMouseButton )
	if self.Config.TemplateList ~= nil then
		local selectedTemplate = self.ConfigForm:FindChild("TemplateListContainer"):GetRadioSel("Template")
		if selectedTemplate ~= 0 then
			self.Config.bMaxHealth = self.Config.TemplateList[selectedTemplate].tMaxHealth
			self.Config.bMaxShield = self.Config.TemplateList[selectedTemplate].tMaxShield
			self.Config.bAssaultPower = self.Config.TemplateList[selectedTemplate].tAssaultPower
			self.Config.bSupportPower = self.Config.TemplateList[selectedTemplate].tSupportPower
			self.Config.bArmor = self.Config.TemplateList[selectedTemplate].tArmor
			self.Config.bStrikethrough = self.Config.TemplateList[selectedTemplate].tStrikethrough
			self.Config.bCritChance = self.Config.TemplateList[selectedTemplate].tCritChance
			self.Config.bCritSeverity = self.Config.TemplateList[selectedTemplate].tCritSeverity
			self.Config.bArmorPen = self.Config.TemplateList[selectedTemplate].tArmorPen
			self.Config.bShieldPen = self.Config.TemplateList[selectedTemplate].tShieldPen
			self.Config.bLifesteal = self.Config.TemplateList[selectedTemplate].tLifesteal
			self.Config.bCooldownReduction = self.Config.TemplateList[selectedTemplate].tCooldownReduction
			self.Config.bShieldRegenPercent = self.Config.TemplateList[selectedTemplate].tShieldRegenPercent
			self.Config.bShieldReboot = self.Config.TemplateList[selectedTemplate].tShieldReboot
			self.Config.bPhysicalMit = self.Config.TemplateList[selectedTemplate].tPhysicalMit
			self.Config.bTechMit = self.Config.TemplateList[selectedTemplate].tTechMit
			self.Config.bMagicMit = self.Config.TemplateList[selectedTemplate].tMagicMit
			self.Config.bDeflect = self.Config.TemplateList[selectedTemplate].tDeflect
			self.Config.bDeflectCrit = self.Config.TemplateList[selectedTemplate].tDeflectCrit
			self.Config.bCCDuration = self.Config.TemplateList[selectedTemplate].tCCDuration
			self.Config.bManaRecovery = self.Config.TemplateList[selectedTemplate].tManaRecovery
			self.Config.bManaCostRed = self.Config.TemplateList[selectedTemplate].tManaCostRed
			--self.Config.bPvPOffense = self.Config.TemplateList[selectedTemplate].tPvPOffense
			--self.Config.bPvPHeal = self.Config.TemplateList[selectedTemplate].tPvPHeal
			--self.Config.bPvPDef = self.Config.TemplateList[selectedTemplate].tPvPDef
	
			self:MatchWithConfig()
		end
	end
end


-- ButtonClearAttributes
function DisplayStat:OnClearAttributes( wndHandler, wndControl, eMouseButton )
	self:UnCheckAllAttributes()
end

-- UnCheckAllAttributes
function DisplayStat:UnCheckAllAttributes()
	self.Config.bMaxHealth = false
	self.Config.bMaxShield = false
	self.Config.bAssaultPower = false
	self.Config.bSupportPower = false
	self.Config.bArmor = false
	self.Config.bStrikethrough = false
	self.Config.bCritChance = false
	self.Config.bCritSeverity = false
	self.Config.bArmorPen = false
	self.Config.bShieldPen = false
	self.Config.bLifesteal = false
	self.Config.bCooldownReduction = false
	self.Config.bShieldRegenPercent = false
	self.Config.bShieldReboot = false
	self.Config.bPhysicalMit = false
	self.Config.bTechMit = false
	self.Config.bMagicMit = false
	self.Config.bDeflect = false
	self.Config.bDeflectCrit = false
	self.Config.bCCDuration = false
	self.Config.bManaRecovery = false
	self.Config.bManaCostRed = false
	--self.Config.bPvPOffense = false
	--self.Config.bPvPHeal = false
	--self.Config.bPvPDef = false


	self:MatchWithConfig()

end


---------------------------------------------------------------------------------------------------
-- DisplayStatConfigForm Functions
---------------------------------------------------------------------------------------------------

function DisplayStat:OnConfigMaxHealthCheck( wndHandler, wndControl, eMouseButton )
	self.Config.bMaxHealth = true
	self:NewAttributeContainer(self.Config.Attribute.MaxHealth)
end

function DisplayStat:OnConfigMaxHealthUnCheck( wndHandler, wndControl, eMouseButton )
	self.Config.bMaxHealth = false
	self:DestroyAttributeContainer(self.Config.Attribute.MaxHealth)
end

function DisplayStat:OnConfigMaxShieldCheck( wndHandler, wndControl, eMouseButton )
	self.Config.bMaxShield = true
	self:NewAttributeContainer(self.Config.Attribute.MaxShield)
end

function DisplayStat:OnConfigMaxShieldUnCheck( wndHandler, wndControl, eMouseButton )
	self.Config.bMaxShield = false
	self:DestroyAttributeContainer(self.Config.Attribute.MaxShield)
end

function DisplayStat:OnConfigAssaultPowerCheck( wndHandler, wndControl, eMouseButton )
	self.Config.bAssaultPower = true
	self:NewAttributeContainer(self.Config.Attribute.AssaultPower)
end

function DisplayStat:OnConfigAssaultPowerUnCheck( wndHandler, wndControl, eMouseButton )
	self.Config.bAssaultPower = false
	self:DestroyAttributeContainer(self.Config.Attribute.AssaultPower)
end

function DisplayStat:OnConfigSupportPowerCheck( wndHandler, wndControl, eMouseButton )
	self.Config.bSupportPower = true
	self:NewAttributeContainer(self.Config.Attribute.SupportPower)
end

function DisplayStat:OnConfigSupportPowerUnCheck( wndHandler, wndControl, eMouseButton )
	self.Config.bSupportPower = false
	self:DestroyAttributeContainer(self.Config.Attribute.SupportPower)
end

function DisplayStat:OnConfigArmorCheck( wndHandler, wndControl, eMouseButton )
	self.Config.bArmor = true
	self:NewAttributeContainer(self.Config.Attribute.Armor)
end

function DisplayStat:OnConfigArmorUnCheck( wndHandler, wndControl, eMouseButton )
	self.Config.bArmor = false
	self:DestroyAttributeContainer(self.Config.Attribute.Armor)
end

function DisplayStat:OnConfigStrikethroughCheck( wndHandler, wndControl, eMouseButton )
	self.Config.bStrikethrough = true
	self:NewAttributeContainer(self.Config.Attribute.Strikethrough)
end

function DisplayStat:OnConfigStrikethroughUnCheck( wndHandler, wndControl, eMouseButton )
	self.Config.bStrikethrough = false
	self:DestroyAttributeContainer(self.Config.Attribute.Strikethrough)
end

function DisplayStat:OnConfigCritChanceCheck( wndHandler, wndControl, eMouseButton )
	self.Config.bCritChance = true
	self:NewAttributeContainer(self.Config.Attribute.CritChance)
end

function DisplayStat:OnConfigCritChanceUnCheck( wndHandler, wndControl, eMouseButton )
	self.Config.bCritChance = false
	self:DestroyAttributeContainer(self.Config.Attribute.CritChance)
end

function DisplayStat:OnConfigCritSeverityCheck( wndHandler, wndControl, eMouseButton )
	self.Config.bCritSeverity = true
	self:NewAttributeContainer(self.Config.Attribute.CritSeverity)
end

function DisplayStat:OnConfigCritSeverityUnCheck( wndHandler, wndControl, eMouseButton )
	self.Config.bCritSeverity = false
	self:DestroyAttributeContainer(self.Config.Attribute.CritSeverity)
end

function DisplayStat:OnConfigArmorPenCheck( wndHandler, wndControl, eMouseButton )
	self.Config.bArmorPen = true
	self:NewAttributeContainer(self.Config.Attribute.ArmorPen)
end

function DisplayStat:OnConfigArmorPenUnCheck( wndHandler, wndControl, eMouseButton )
	self.Config.bArmorPen = false
	self:DestroyAttributeContainer(self.Config.Attribute.ArmorPen)
end

function DisplayStat:OnConfigShieldPenCheck( wndHandler, wndControl, eMouseButton )
	self.Config.bShieldPen = true
	self:NewAttributeContainer(self.Config.Attribute.ShieldPen)
end

function DisplayStat:OnConfigShieldPenUnCheck( wndHandler, wndControl, eMouseButton )
	self.Config.bShieldPen = false
	self:DestroyAttributeContainer(self.Config.Attribute.ShieldPen)
end

function DisplayStat:OnConfigLifestealCheck( wndHandler, wndControl, eMouseButton )
	self.Config.bLifesteal = true
	self:NewAttributeContainer(self.Config.Attribute.Lifesteal)
end

function DisplayStat:OnConfigLifestealUnCheck( wndHandler, wndControl, eMouseButton )
	self.Config.bLifesteal = false
	self:DestroyAttributeContainer(self.Config.Attribute.Lifesteal)
end

function DisplayStat:OnConfigCooldownReductionCheck( wndHandler, wndControl, eMouseButton )
	self.Config.bCooldownReduction = true
	self:NewAttributeContainer(self.Config.Attribute.CooldownReduction)
end

function DisplayStat:OnConfigCooldownReductionUnCheck( wndHandler, wndControl, eMouseButton )
	self.Config.bCooldownReduction = false
	self:DestroyAttributeContainer(self.Config.Attribute.CooldownReduction)
end

function DisplayStat:OnConfigShieldRegenPercentCheck( wndHandler, wndControl, eMouseButton )
	self.Config.bShieldRegenPercent = true
	self:NewAttributeContainer(self.Config.Attribute.ShieldRegenPercent)
end

function DisplayStat:OnConfigShieldRegenPercentUnCheck( wndHandler, wndControl, eMouseButton )
	self.Config.bShieldRegenPercent = false
	self:DestroyAttributeContainer(self.Config.Attribute.ShieldRegenPercent)
end

function DisplayStat:OnConfigShieldRebootCheck( wndHandler, wndControl, eMouseButton )
	self.Config.bShieldReboot = true
	self:NewAttributeContainer(self.Config.Attribute.ShieldReboot)
end

function DisplayStat:OnConfigShieldRebootUnCheck( wndHandler, wndControl, eMouseButton )
	self.Config.bShieldReboot = false
	self:DestroyAttributeContainer(self.Config.Attribute.ShieldReboot)
end

function DisplayStat:OnConfigPhysicalMitCheck( wndHandler, wndControl, eMouseButton )
	self.Config.bPhysicalMit = true
	self:NewAttributeContainer(self.Config.Attribute.PhysicalMit)
end

function DisplayStat:OnConfigPhysicalMitUnCheck( wndHandler, wndControl, eMouseButton )
	self.Config.bPhysicalMit = false
	self:DestroyAttributeContainer(self.Config.Attribute.PhysicalMit)
end

function DisplayStat:OnConfigTechMitCheck( wndHandler, wndControl, eMouseButton )
	self.Config.bTechMit = true
	self:NewAttributeContainer(self.Config.Attribute.TechMit)
end

function DisplayStat:OnConfigTechMitUnCheck( wndHandler, wndControl, eMouseButton )
	self.Config.bTechMit = false
	self:DestroyAttributeContainer(self.Config.Attribute.TechMit)
end

function DisplayStat:OnConfigMagicMitCheck( wndHandler, wndControl, eMouseButton )
	self.Config.bMagicMit = true
	self:NewAttributeContainer(self.Config.Attribute.MagicMit)
end

function DisplayStat:OnConfigMagicMitUnCheck( wndHandler, wndControl, eMouseButton )
	self.Config.bMagicMit = false
	self:DestroyAttributeContainer(self.Config.Attribute.MagicMit)
end

function DisplayStat:OnConfigDeflectCheck( wndHandler, wndControl, eMouseButton )
	self.Config.bDeflect = true
	self:NewAttributeContainer(self.Config.Attribute.Deflect)
end

function DisplayStat:OnConfigDeflectUnCheck( wndHandler, wndControl, eMouseButton )
	self.Config.bDeflect = false
	self:DestroyAttributeContainer(self.Config.Attribute.Deflect)
end

function DisplayStat:OnConfigDeflectCritCheck( wndHandler, wndControl, eMouseButton )
	self.Config.bDeflectCrit = true
	self:NewAttributeContainer(self.Config.Attribute.DeflectCrit)
end

function DisplayStat:OnConfigDeflectCritUnCheck( wndHandler, wndControl, eMouseButton )
	self.Config.bDeflectCrit = false
	self:DestroyAttributeContainer(self.Config.Attribute.DeflectCrit)
end

function DisplayStat:OnConfigCCDurationCheck( wndHandler, wndControl, eMouseButton )
	self.Config.bCCDuration = true
	self:NewAttributeContainer(self.Config.Attribute.CCDuration)
end

function DisplayStat:OnConfigCCDurationUnCheck( wndHandler, wndControl, eMouseButton )
	self.Config.bCCDuration = false
	self:DestroyAttributeContainer(self.Config.Attribute.CCDuration)
end

function DisplayStat:OnConfigManaRecoveryCheck( wndHandler, wndControl, eMouseButton )
	self.Config.bManaRecovery = true
	self:NewAttributeContainer(self.Config.Attribute.ManaRecovery)
end

function DisplayStat:OnConfigManaRecoveryUnCheck( wndHandler, wndControl, eMouseButton )
	self.Config.bManaRecovery = false
	self:DestroyAttributeContainer(self.Config.Attribute.ManaRecovery)
end

function DisplayStat:OnConfigManaCostRedCheck( wndHandler, wndControl, eMouseButton )
	self.Config.bManaCostRed = true
	self:NewAttributeContainer(self.Config.Attribute.ManaCostRed)
end

function DisplayStat:OnConfigManaCostRedUnCheck( wndHandler, wndControl, eMouseButton )
	self.Config.bManaCostRed = false
	self:DestroyAttributeContainer(self.Config.Attribute.ManaCostRed)
end

--[[function DisplayStat:OnConfigPvPOffenseCheck( wndHandler, wndControl, eMouseButton )
	self.Config.bPvPOffense = true
	self:NewAttributeContainer(self.Config.Attribute.PvPOffense)
end

function DisplayStat:OnConfigPvPOffenseUnCheck( wndHandler, wndControl, eMouseButton )
	self.Config.bPvPOffense = false
	self:DestroyAttributeContainer(self.Config.Attribute.PvPOffense)
end

function DisplayStat:OnConfigPvPHealCheck( wndHandler, wndControl, eMouseButton )
	self.Config.bPvPHeal = true
	self:NewAttributeContainer(self.Config.Attribute.PvPHeal)
end

function DisplayStat:OnConfigPvPHealUnCheck( wndHandler, wndControl, eMouseButton )
	self.Config.bPvPHeal = false
	self:DestroyAttributeContainer(self.Config.Attribute.PvPHeal)
end

function DisplayStat:OnConfigPvPDefCheck( wndHandler, wndControl, eMouseButton )
	self.Config.bPvPDef = true
	self:NewAttributeContainer(self.Config.Attribute.PvPDef)
end

function DisplayStat:OnConfigPvPDefUnCheck( wndHandler, wndControl, eMouseButton )
	self.Config.bPvPDef = false
	self:DestroyAttributeContainer(self.Config.Attribute.PvPDef)
end]]







--****************************************************************************************************
-- DisplayStat Instance
--****************************************************************************************************
local DisplayStatInst = DisplayStat:new()
DisplayStatInst:Init()
















function DisplayStat:OnCustomNameWindowCheck( wndHandler, wndControl, eMouseButton )
end

function DisplayStat:OnCustomNameWindowUnCheck( wndHandler, wndControl, eMouseButton )
end

